@@ -25,7 +25,7 @@
 #include "dh-util.h"
 #include "dh-preferences.h"
 #include "ige-conf.h"
-#include "dh-base.h"
+#include "dh-app.h"
 
 typedef struct {
         GtkWidget     *dialog;
@@ -119,22 +119,32 @@ static DhPreferences *prefs;
 static void
 preferences_init (void)
 {
-        if (!prefs) {
-                prefs = g_new0 (DhPreferences, 1);
-                prefs->book_manager = dh_base_get_book_manager (dh_base_get ());
-                g_signal_connect (prefs->book_manager,
-                                  "book-created",
-                                  G_CALLBACK (preferences_bookshelf_book_created_cb),
-                                  NULL);
-                g_signal_connect (prefs->book_manager,
-                                  "book-deleted",
-                                  G_CALLBACK (preferences_bookshelf_book_deleted_cb),
-                                  NULL);
-                g_signal_connect (prefs->book_manager,
-                                  "notify::group-by-language",
-                                  G_CALLBACK (preferences_bookshelf_group_by_language_cb),
-                                  NULL);
+        GApplication *app;
+
+        if (prefs) {
+                return;
         }
+
+        app = g_application_get_default ();
+        if (!app) {
+                g_warning ("Cannot launch Preferences: No default application found");
+                return;
+        }
+
+        prefs = g_new0 (DhPreferences, 1);
+        prefs->book_manager = g_object_ref (dh_app_peek_book_manager (DH_APP (app)));
+        g_signal_connect (prefs->book_manager,
+                          "book-created",
+                          G_CALLBACK (preferences_bookshelf_book_created_cb),
+                          NULL);
+        g_signal_connect (prefs->book_manager,
+                          "book-deleted",
+                          G_CALLBACK (preferences_bookshelf_book_deleted_cb),
+                          NULL);
+        g_signal_connect (prefs->book_manager,
+                          "notify::group-by-language",
+                          G_CALLBACK (preferences_bookshelf_group_by_language_cb),
+                          NULL);
 }
 
 static void
@@ -144,6 +154,7 @@ preferences_shutdown (void)
                 return;
         }
 
+        g_object_unref (prefs->book_manager);
         gtk_list_store_clear (prefs->bookshelf_store);
         gtk_widget_destroy (GTK_WIDGET (prefs->dialog));
 
@@ -287,41 +298,21 @@ preferences_connect_conf_listeners (void)
 }
 #endif
 
-/* FIXME: Use the functions in dh-util.c for this. */
 static void
 preferences_fonts_get_font_names (gboolean   use_system_fonts,
                                   gchar    **variable,
                                   gchar    **fixed)
 {
-	gchar   *var_font_name;
-        gchar   *fixed_font_name;
-	IgeConf *conf;
+	gchar   *name;
+	gdouble  size;
 
-	conf = ige_conf_get ();
+	dh_util_font_get_variable (&name, &size, use_system_fonts);
+	*variable = g_strdup_printf ("%s %u", name, (guint)size);
+	g_free (name);
 
-	if (use_system_fonts) {
-#ifdef GDK_WINDOWING_QUARTZ
-                var_font_name = g_strdup ("Lucida Grande 14");
-                fixed_font_name = g_strdup ("Monaco 14");
-#else
-		ige_conf_get_string (conf,
-                                     DH_CONF_SYSTEM_VARIABLE_FONT,
-                                     &var_font_name);
-		ige_conf_get_string (conf,
-                                     DH_CONF_SYSTEM_FIXED_FONT,
-                                     &fixed_font_name);
-#endif
-	} else {
-		ige_conf_get_string (conf,
-                                     DH_CONF_VARIABLE_FONT,
-                                     &var_font_name);
-                ige_conf_get_string (conf,
-                                     DH_CONF_FIXED_FONT,
-                                     &fixed_font_name);
-	}
-
-	*variable = var_font_name;
-	*fixed = fixed_font_name;
+	dh_util_font_get_fixed (&name, &size, use_system_fonts);
+	*fixed = g_strdup_printf ("%s %u", name, (guint)size);
+	g_free (name);
 }
 
 static void
@@ -825,7 +816,7 @@ preferences_bookshelf_group_by_language_toggled_cb (GtkToggleButton *button,
 }
 
 void
-dh_preferences_show_dialog (GtkWindow *parent)
+dh_preferences_show_dialog (void)
 {
         gchar      *path;
 	GtkBuilder *builder;
@@ -900,6 +891,5 @@ dh_preferences_show_dialog (GtkWindow *parent)
                           G_CALLBACK (preferences_dialog_response),
                           NULL);
 
-	gtk_window_set_transient_for (GTK_WINDOW (prefs->dialog), parent);
 	gtk_widget_show_all (prefs->dialog);
 }
